# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 authentication_domain_id: pulumi.Input[builtins.str],
                 email_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the user to be created would belong.
        :param pulumi.Input[builtins.str] email_id: The email ID of the user to be created.
        :param pulumi.Input[builtins.str] name: The name of the user to be created.
        :param pulumi.Input[builtins.str] user_type: The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        pulumi.set(__self__, "email_id", email_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the authentication domain to which the user to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @authentication_domain_id.setter
    def authentication_domain_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "authentication_domain_id", value)

    @property
    @pulumi.getter(name="emailId")
    def email_id(self) -> pulumi.Input[builtins.str]:
        """
        The email ID of the user to be created.
        """
        return pulumi.get(self, "email_id")

    @email_id.setter
    def email_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "email_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the user to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_type", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 email_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the user to be created would belong.
        :param pulumi.Input[builtins.str] email_id: The email ID of the user to be created.
        :param pulumi.Input[builtins.str] name: The name of the user to be created.
        :param pulumi.Input[builtins.str] user_type: The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        if authentication_domain_id is not None:
            pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        if email_id is not None:
            pulumi.set(__self__, "email_id", email_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the authentication domain to which the user to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @authentication_domain_id.setter
    def authentication_domain_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_domain_id", value)

    @property
    @pulumi.getter(name="emailId")
    def email_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The email ID of the user to be created.
        """
        return pulumi.get(self, "email_id")

    @email_id.setter
    def email_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the user to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_type", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 email_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The `User` resource may be used to create, update and delete users in New Relic.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
        foo_user = newrelic.User("foo",
            name="Test New User",
            email_id="test_user@test.com",
            authentication_domain_id=foo.id,
            user_type="CORE_USER_TIER")
        ```

        ## Import

        A user can be imported using its ID. Example:

        ```sh
        $ pulumi import newrelic:index/user:User foo 1999999999
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the user to be created would belong.
        :param pulumi.Input[builtins.str] email_id: The email ID of the user to be created.
        :param pulumi.Input[builtins.str] name: The name of the user to be created.
        :param pulumi.Input[builtins.str] user_type: The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `User` resource may be used to create, update and delete users in New Relic.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
        foo_user = newrelic.User("foo",
            name="Test New User",
            email_id="test_user@test.com",
            authentication_domain_id=foo.id,
            user_type="CORE_USER_TIER")
        ```

        ## Import

        A user can be imported using its ID. Example:

        ```sh
        $ pulumi import newrelic:index/user:User foo 1999999999
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 email_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if authentication_domain_id is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_domain_id'")
            __props__.__dict__["authentication_domain_id"] = authentication_domain_id
            if email_id is None and not opts.urn:
                raise TypeError("Missing required property 'email_id'")
            __props__.__dict__["email_id"] = email_id
            __props__.__dict__["name"] = name
            __props__.__dict__["user_type"] = user_type
        super(User, __self__).__init__(
            'newrelic:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
            email_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            user_type: Optional[pulumi.Input[builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the user to be created would belong.
        :param pulumi.Input[builtins.str] email_id: The email ID of the user to be created.
        :param pulumi.Input[builtins.str] name: The name of the user to be created.
        :param pulumi.Input[builtins.str] user_type: The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["authentication_domain_id"] = authentication_domain_id
        __props__.__dict__["email_id"] = email_id
        __props__.__dict__["name"] = name
        __props__.__dict__["user_type"] = user_type
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the authentication domain to which the user to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @property
    @pulumi.getter(name="emailId")
    def email_id(self) -> pulumi.Output[builtins.str]:
        """
        The email ID of the user to be created.
        """
        return pulumi.get(self, "email_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the user to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The tier to which the user to be created would belong. Accepted values for this argument are `BASIC_USER_TIER`, `CORE_USER_TIER`, or `FULL_USER_TIER`. If not specified in the configuration, the argument would default to `BASIC_USER_TIER`.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `User` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing user is not supported.
        """
        return pulumi.get(self, "user_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ApplicationSettingsErrorCollectorArgs',
    'ApplicationSettingsErrorCollectorArgsDict',
    'ApplicationSettingsTransactionTracerArgs',
    'ApplicationSettingsTransactionTracerArgsDict',
    'ApplicationSettingsTransactionTracerExplainQueryPlanArgs',
    'ApplicationSettingsTransactionTracerExplainQueryPlanArgsDict',
    'ApplicationSettingsTransactionTracerSqlArgs',
    'ApplicationSettingsTransactionTracerSqlArgsDict',
    'WorkloadEntitySearchQueryArgs',
    'WorkloadEntitySearchQueryArgsDict',
    'WorkloadStatusConfigAutomaticArgs',
    'WorkloadStatusConfigAutomaticArgsDict',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgsDict',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgsDict',
    'WorkloadStatusConfigAutomaticRuleArgs',
    'WorkloadStatusConfigAutomaticRuleArgsDict',
    'WorkloadStatusConfigAutomaticRuleNrqlQueryArgs',
    'WorkloadStatusConfigAutomaticRuleNrqlQueryArgsDict',
    'WorkloadStatusConfigAutomaticRuleRollupArgs',
    'WorkloadStatusConfigAutomaticRuleRollupArgsDict',
    'WorkloadStatusConfigStaticArgs',
    'WorkloadStatusConfigStaticArgsDict',
]

MYPY = False

if not MYPY:
    class ApplicationSettingsErrorCollectorArgsDict(TypedDict):
        expected_error_classes: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        A list of expected error classes.
        """
        expected_error_codes: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        A list of expected error codes(any status code between 100-900).
        """
        ignored_error_classes: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        A list of ignored error classes.
        """
        ignored_error_codes: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        A list of ignored error codes(any status code between 100-900).
        """
elif False:
    ApplicationSettingsErrorCollectorArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ApplicationSettingsErrorCollectorArgs:
    def __init__(__self__, *,
                 expected_error_classes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 expected_error_codes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ignored_error_classes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ignored_error_codes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] expected_error_classes: A list of expected error classes.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] expected_error_codes: A list of expected error codes(any status code between 100-900).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ignored_error_classes: A list of ignored error classes.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ignored_error_codes: A list of ignored error codes(any status code between 100-900).
        """
        if expected_error_classes is not None:
            pulumi.set(__self__, "expected_error_classes", expected_error_classes)
        if expected_error_codes is not None:
            pulumi.set(__self__, "expected_error_codes", expected_error_codes)
        if ignored_error_classes is not None:
            pulumi.set(__self__, "ignored_error_classes", ignored_error_classes)
        if ignored_error_codes is not None:
            pulumi.set(__self__, "ignored_error_codes", ignored_error_codes)

    @property
    @pulumi.getter(name="expectedErrorClasses")
    def expected_error_classes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of expected error classes.
        """
        return pulumi.get(self, "expected_error_classes")

    @expected_error_classes.setter
    def expected_error_classes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "expected_error_classes", value)

    @property
    @pulumi.getter(name="expectedErrorCodes")
    def expected_error_codes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of expected error codes(any status code between 100-900).
        """
        return pulumi.get(self, "expected_error_codes")

    @expected_error_codes.setter
    def expected_error_codes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "expected_error_codes", value)

    @property
    @pulumi.getter(name="ignoredErrorClasses")
    def ignored_error_classes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of ignored error classes.
        """
        return pulumi.get(self, "ignored_error_classes")

    @ignored_error_classes.setter
    def ignored_error_classes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ignored_error_classes", value)

    @property
    @pulumi.getter(name="ignoredErrorCodes")
    def ignored_error_codes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of ignored error codes(any status code between 100-900).
        """
        return pulumi.get(self, "ignored_error_codes")

    @ignored_error_codes.setter
    def ignored_error_codes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ignored_error_codes", value)


if not MYPY:
    class ApplicationSettingsTransactionTracerArgsDict(TypedDict):
        explain_query_plans: NotRequired[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerExplainQueryPlanArgsDict']]]]
        """
        Configuration block for query plans. Including this block enables the capture of query plans. The following arguments are supported:
        """
        sql: NotRequired[pulumi.Input['ApplicationSettingsTransactionTracerSqlArgsDict']]
        """
        Configuration block for SQL logging.  Including this block enables SQL logging. The following arguments are supported:
        """
        stack_trace_threshold_value: NotRequired[pulumi.Input[builtins.float]]
        """
        The response time threshold for collecting stack traces.
        """
        transaction_threshold_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of threshold for transactions. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        transaction_threshold_value: NotRequired[pulumi.Input[builtins.float]]
        """
        The threshold value for transactions(in seconds).
        """
elif False:
    ApplicationSettingsTransactionTracerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ApplicationSettingsTransactionTracerArgs:
    def __init__(__self__, *,
                 explain_query_plans: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerExplainQueryPlanArgs']]]] = None,
                 sql: Optional[pulumi.Input['ApplicationSettingsTransactionTracerSqlArgs']] = None,
                 stack_trace_threshold_value: Optional[pulumi.Input[builtins.float]] = None,
                 transaction_threshold_type: Optional[pulumi.Input[builtins.str]] = None,
                 transaction_threshold_value: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerExplainQueryPlanArgs']]] explain_query_plans: Configuration block for query plans. Including this block enables the capture of query plans. The following arguments are supported:
        :param pulumi.Input['ApplicationSettingsTransactionTracerSqlArgs'] sql: Configuration block for SQL logging.  Including this block enables SQL logging. The following arguments are supported:
        :param pulumi.Input[builtins.float] stack_trace_threshold_value: The response time threshold for collecting stack traces.
        :param pulumi.Input[builtins.str] transaction_threshold_type: The type of threshold for transactions. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        :param pulumi.Input[builtins.float] transaction_threshold_value: The threshold value for transactions(in seconds).
        """
        if explain_query_plans is not None:
            pulumi.set(__self__, "explain_query_plans", explain_query_plans)
        if sql is not None:
            pulumi.set(__self__, "sql", sql)
        if stack_trace_threshold_value is not None:
            pulumi.set(__self__, "stack_trace_threshold_value", stack_trace_threshold_value)
        if transaction_threshold_type is not None:
            pulumi.set(__self__, "transaction_threshold_type", transaction_threshold_type)
        if transaction_threshold_value is not None:
            pulumi.set(__self__, "transaction_threshold_value", transaction_threshold_value)

    @property
    @pulumi.getter(name="explainQueryPlans")
    def explain_query_plans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerExplainQueryPlanArgs']]]]:
        """
        Configuration block for query plans. Including this block enables the capture of query plans. The following arguments are supported:
        """
        return pulumi.get(self, "explain_query_plans")

    @explain_query_plans.setter
    def explain_query_plans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerExplainQueryPlanArgs']]]]):
        pulumi.set(self, "explain_query_plans", value)

    @property
    @pulumi.getter
    def sql(self) -> Optional[pulumi.Input['ApplicationSettingsTransactionTracerSqlArgs']]:
        """
        Configuration block for SQL logging.  Including this block enables SQL logging. The following arguments are supported:
        """
        return pulumi.get(self, "sql")

    @sql.setter
    def sql(self, value: Optional[pulumi.Input['ApplicationSettingsTransactionTracerSqlArgs']]):
        pulumi.set(self, "sql", value)

    @property
    @pulumi.getter(name="stackTraceThresholdValue")
    def stack_trace_threshold_value(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        The response time threshold for collecting stack traces.
        """
        return pulumi.get(self, "stack_trace_threshold_value")

    @stack_trace_threshold_value.setter
    def stack_trace_threshold_value(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "stack_trace_threshold_value", value)

    @property
    @pulumi.getter(name="transactionThresholdType")
    def transaction_threshold_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of threshold for transactions. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        return pulumi.get(self, "transaction_threshold_type")

    @transaction_threshold_type.setter
    def transaction_threshold_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transaction_threshold_type", value)

    @property
    @pulumi.getter(name="transactionThresholdValue")
    def transaction_threshold_value(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        The threshold value for transactions(in seconds).
        """
        return pulumi.get(self, "transaction_threshold_value")

    @transaction_threshold_value.setter
    def transaction_threshold_value(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "transaction_threshold_value", value)


if not MYPY:
    class ApplicationSettingsTransactionTracerExplainQueryPlanArgsDict(TypedDict):
        query_plan_threshold_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of threshold for query plans. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        query_plan_threshold_value: NotRequired[pulumi.Input[builtins.float]]
        """
        The response time threshold for capturing query plans(in seconds).
        """
elif False:
    ApplicationSettingsTransactionTracerExplainQueryPlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ApplicationSettingsTransactionTracerExplainQueryPlanArgs:
    def __init__(__self__, *,
                 query_plan_threshold_type: Optional[pulumi.Input[builtins.str]] = None,
                 query_plan_threshold_value: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] query_plan_threshold_type: The type of threshold for query plans. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        :param pulumi.Input[builtins.float] query_plan_threshold_value: The response time threshold for capturing query plans(in seconds).
        """
        if query_plan_threshold_type is not None:
            pulumi.set(__self__, "query_plan_threshold_type", query_plan_threshold_type)
        if query_plan_threshold_value is not None:
            pulumi.set(__self__, "query_plan_threshold_value", query_plan_threshold_value)

    @property
    @pulumi.getter(name="queryPlanThresholdType")
    def query_plan_threshold_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of threshold for query plans. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        return pulumi.get(self, "query_plan_threshold_type")

    @query_plan_threshold_type.setter
    def query_plan_threshold_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_plan_threshold_type", value)

    @property
    @pulumi.getter(name="queryPlanThresholdValue")
    def query_plan_threshold_value(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        The response time threshold for capturing query plans(in seconds).
        """
        return pulumi.get(self, "query_plan_threshold_value")

    @query_plan_threshold_value.setter
    def query_plan_threshold_value(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "query_plan_threshold_value", value)


if not MYPY:
    class ApplicationSettingsTransactionTracerSqlArgsDict(TypedDict):
        record_sql: pulumi.Input[builtins.str]
        """
        The level of SQL recording. Valid values ar `OBFUSCATED`,`OFF`,`RAW` (Mandatory attribute when `sql` block is provided).
        """
elif False:
    ApplicationSettingsTransactionTracerSqlArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ApplicationSettingsTransactionTracerSqlArgs:
    def __init__(__self__, *,
                 record_sql: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] record_sql: The level of SQL recording. Valid values ar `OBFUSCATED`,`OFF`,`RAW` (Mandatory attribute when `sql` block is provided).
        """
        pulumi.set(__self__, "record_sql", record_sql)

    @property
    @pulumi.getter(name="recordSql")
    def record_sql(self) -> pulumi.Input[builtins.str]:
        """
        The level of SQL recording. Valid values ar `OBFUSCATED`,`OFF`,`RAW` (Mandatory attribute when `sql` block is provided).
        """
        return pulumi.get(self, "record_sql")

    @record_sql.setter
    def record_sql(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "record_sql", value)


if not MYPY:
    class WorkloadEntitySearchQueryArgsDict(TypedDict):
        query: pulumi.Input[builtins.str]
        """
        A valid entity search query; empty, and null values are considered invalid.
        """
elif False:
    WorkloadEntitySearchQueryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadEntitySearchQueryArgs:
    def __init__(__self__, *,
                 query: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] query: A valid entity search query; empty, and null values are considered invalid.
        """
        pulumi.set(__self__, "query", query)

    @property
    @pulumi.getter
    def query(self) -> pulumi.Input[builtins.str]:
        """
        A valid entity search query; empty, and null values are considered invalid.
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "query", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticArgsDict(TypedDict):
        enabled: pulumi.Input[builtins.bool]
        """
        Whether the automatic status configuration is enabled or not.
        """
        remaining_entities_rule: NotRequired[pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgsDict']]
        """
        An additional meta-rule that can consider all entities that haven't been evaluated by any other rule.
        """
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleArgsDict']]]]
        """
        A list of rules.
        """
elif False:
    WorkloadStatusConfigAutomaticArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[builtins.bool],
                 remaining_entities_rule: Optional[pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs']] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleArgs']]]] = None):
        """
        :param pulumi.Input[builtins.bool] enabled: Whether the automatic status configuration is enabled or not.
        :param pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs'] remaining_entities_rule: An additional meta-rule that can consider all entities that haven't been evaluated by any other rule.
        :param pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleArgs']]] rules: A list of rules.
        """
        pulumi.set(__self__, "enabled", enabled)
        if remaining_entities_rule is not None:
            pulumi.set(__self__, "remaining_entities_rule", remaining_entities_rule)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[builtins.bool]:
        """
        Whether the automatic status configuration is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="remainingEntitiesRule")
    def remaining_entities_rule(self) -> Optional[pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs']]:
        """
        An additional meta-rule that can consider all entities that haven't been evaluated by any other rule.
        """
        return pulumi.get(self, "remaining_entities_rule")

    @remaining_entities_rule.setter
    def remaining_entities_rule(self, value: Optional[pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs']]):
        pulumi.set(self, "remaining_entities_rule", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleArgs']]]]:
        """
        A list of rules.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleArgs']]]]):
        pulumi.set(self, "rules", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgsDict(TypedDict):
        remaining_entities_rule_rollup: pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgsDict']
        """
        The input object used to represent a rollup strategy.
        """
elif False:
    WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs:
    def __init__(__self__, *,
                 remaining_entities_rule_rollup: pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs']):
        """
        :param pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs'] remaining_entities_rule_rollup: The input object used to represent a rollup strategy.
        """
        pulumi.set(__self__, "remaining_entities_rule_rollup", remaining_entities_rule_rollup)

    @property
    @pulumi.getter(name="remainingEntitiesRuleRollup")
    def remaining_entities_rule_rollup(self) -> pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs']:
        """
        The input object used to represent a rollup strategy.
        """
        return pulumi.get(self, "remaining_entities_rule_rollup")

    @remaining_entities_rule_rollup.setter
    def remaining_entities_rule_rollup(self, value: pulumi.Input['WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs']):
        pulumi.set(self, "remaining_entities_rule_rollup", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgsDict(TypedDict):
        group_by: pulumi.Input[builtins.str]
        """
        The grouping to be applied to the remaining entities.
        """
        strategy: pulumi.Input[builtins.str]
        """
        The rollup strategy that is applied to a group of entities.
        """
        threshold_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        threshold_value: NotRequired[pulumi.Input[builtins.int]]
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
elif False:
    WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs:
    def __init__(__self__, *,
                 group_by: pulumi.Input[builtins.str],
                 strategy: pulumi.Input[builtins.str],
                 threshold_type: Optional[pulumi.Input[builtins.str]] = None,
                 threshold_value: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] group_by: The grouping to be applied to the remaining entities.
        :param pulumi.Input[builtins.str] strategy: The rollup strategy that is applied to a group of entities.
        :param pulumi.Input[builtins.str] threshold_type: Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        :param pulumi.Input[builtins.int] threshold_value: Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        pulumi.set(__self__, "group_by", group_by)
        pulumi.set(__self__, "strategy", strategy)
        if threshold_type is not None:
            pulumi.set(__self__, "threshold_type", threshold_type)
        if threshold_value is not None:
            pulumi.set(__self__, "threshold_value", threshold_value)

    @property
    @pulumi.getter(name="groupBy")
    def group_by(self) -> pulumi.Input[builtins.str]:
        """
        The grouping to be applied to the remaining entities.
        """
        return pulumi.get(self, "group_by")

    @group_by.setter
    def group_by(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_by", value)

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Input[builtins.str]:
        """
        The rollup strategy that is applied to a group of entities.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "strategy", value)

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        return pulumi.get(self, "threshold_type")

    @threshold_type.setter
    def threshold_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "threshold_type", value)

    @property
    @pulumi.getter(name="thresholdValue")
    def threshold_value(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        return pulumi.get(self, "threshold_value")

    @threshold_value.setter
    def threshold_value(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "threshold_value", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticRuleArgsDict(TypedDict):
        rollup: pulumi.Input['WorkloadStatusConfigAutomaticRuleRollupArgsDict']
        """
        The input object used to represent a rollup strategy. See Nested rollup blocks below for details.
        """
        entity_guids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        A list of entity GUIDs composing the rule. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        nrql_queries: NotRequired[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleNrqlQueryArgsDict']]]]
        """
        A list of entity search queries used to retrieve the entities that compose the rule. See Nested nrql_query blocks below for details. At least one of `entity_guids` or `nrql_query` must be defined.
        """
elif False:
    WorkloadStatusConfigAutomaticRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticRuleArgs:
    def __init__(__self__, *,
                 rollup: pulumi.Input['WorkloadStatusConfigAutomaticRuleRollupArgs'],
                 entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 nrql_queries: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleNrqlQueryArgs']]]] = None):
        """
        :param pulumi.Input['WorkloadStatusConfigAutomaticRuleRollupArgs'] rollup: The input object used to represent a rollup strategy. See Nested rollup blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] entity_guids: A list of entity GUIDs composing the rule. At least one of `entity_guids` or `nrql_query` must be defined.
        :param pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleNrqlQueryArgs']]] nrql_queries: A list of entity search queries used to retrieve the entities that compose the rule. See Nested nrql_query blocks below for details. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        pulumi.set(__self__, "rollup", rollup)
        if entity_guids is not None:
            pulumi.set(__self__, "entity_guids", entity_guids)
        if nrql_queries is not None:
            pulumi.set(__self__, "nrql_queries", nrql_queries)

    @property
    @pulumi.getter
    def rollup(self) -> pulumi.Input['WorkloadStatusConfigAutomaticRuleRollupArgs']:
        """
        The input object used to represent a rollup strategy. See Nested rollup blocks below for details.
        """
        return pulumi.get(self, "rollup")

    @rollup.setter
    def rollup(self, value: pulumi.Input['WorkloadStatusConfigAutomaticRuleRollupArgs']):
        pulumi.set(self, "rollup", value)

    @property
    @pulumi.getter(name="entityGuids")
    def entity_guids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of entity GUIDs composing the rule. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        return pulumi.get(self, "entity_guids")

    @entity_guids.setter
    def entity_guids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "entity_guids", value)

    @property
    @pulumi.getter(name="nrqlQueries")
    def nrql_queries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleNrqlQueryArgs']]]]:
        """
        A list of entity search queries used to retrieve the entities that compose the rule. See Nested nrql_query blocks below for details. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        return pulumi.get(self, "nrql_queries")

    @nrql_queries.setter
    def nrql_queries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadStatusConfigAutomaticRuleNrqlQueryArgs']]]]):
        pulumi.set(self, "nrql_queries", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticRuleNrqlQueryArgsDict(TypedDict):
        query: pulumi.Input[builtins.str]
        """
        The entity search query that is used to perform the search of a group of entities.
        """
elif False:
    WorkloadStatusConfigAutomaticRuleNrqlQueryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticRuleNrqlQueryArgs:
    def __init__(__self__, *,
                 query: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] query: The entity search query that is used to perform the search of a group of entities.
        """
        pulumi.set(__self__, "query", query)

    @property
    @pulumi.getter
    def query(self) -> pulumi.Input[builtins.str]:
        """
        The entity search query that is used to perform the search of a group of entities.
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "query", value)


if not MYPY:
    class WorkloadStatusConfigAutomaticRuleRollupArgsDict(TypedDict):
        strategy: pulumi.Input[builtins.str]
        """
        The rollup strategy that is applied to a group of entities.
        """
        threshold_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        threshold_value: NotRequired[pulumi.Input[builtins.int]]
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
elif False:
    WorkloadStatusConfigAutomaticRuleRollupArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigAutomaticRuleRollupArgs:
    def __init__(__self__, *,
                 strategy: pulumi.Input[builtins.str],
                 threshold_type: Optional[pulumi.Input[builtins.str]] = None,
                 threshold_value: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] strategy: The rollup strategy that is applied to a group of entities.
        :param pulumi.Input[builtins.str] threshold_type: Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        :param pulumi.Input[builtins.int] threshold_value: Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        pulumi.set(__self__, "strategy", strategy)
        if threshold_type is not None:
            pulumi.set(__self__, "threshold_type", threshold_type)
        if threshold_value is not None:
            pulumi.set(__self__, "threshold_value", threshold_value)

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Input[builtins.str]:
        """
        The rollup strategy that is applied to a group of entities.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "strategy", value)

    @property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        return pulumi.get(self, "threshold_type")

    @threshold_type.setter
    def threshold_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "threshold_type", value)

    @property
    @pulumi.getter(name="thresholdValue")
    def threshold_value(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        return pulumi.get(self, "threshold_value")

    @threshold_value.setter
    def threshold_value(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "threshold_value", value)


if not MYPY:
    class WorkloadStatusConfigStaticArgsDict(TypedDict):
        enabled: pulumi.Input[builtins.bool]
        """
        Whether the static status configuration is enabled or not.
        """
        status: pulumi.Input[builtins.str]
        """
        The status of the workload.
        """
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        Relevant information about the workload.
        """
        summary: NotRequired[pulumi.Input[builtins.str]]
        """
        A short description of the status of the workload.
        """
elif False:
    WorkloadStatusConfigStaticArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkloadStatusConfigStaticArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[builtins.bool],
                 status: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 summary: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] enabled: Whether the static status configuration is enabled or not.
        :param pulumi.Input[builtins.str] status: The status of the workload.
        :param pulumi.Input[builtins.str] description: Relevant information about the workload.
        :param pulumi.Input[builtins.str] summary: A short description of the status of the workload.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "status", status)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if summary is not None:
            pulumi.set(__self__, "summary", summary)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[builtins.bool]:
        """
        Whether the static status configuration is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        The status of the workload.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Relevant information about the workload.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def summary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A short description of the status of the workload.
        """
        return pulumi.get(self, "summary")

    @summary.setter
    def summary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "summary", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EntityTagsArgs', 'EntityTags']

@pulumi.input_type
class EntityTagsArgs:
    def __init__(__self__, *,
                 guid: pulumi.Input[builtins.str],
                 tags: pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]):
        """
        The set of arguments for constructing a EntityTags resource.
        :param pulumi.Input[builtins.str] guid: The guid of the entity to tag.
        :param pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]] tags: A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        pulumi.set(__self__, "guid", guid)
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def guid(self) -> pulumi.Input[builtins.str]:
        """
        The guid of the entity to tag.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "guid", value)

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]:
        """
        A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _EntityTagsState:
    def __init__(__self__, *,
                 guid: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]] = None):
        """
        Input properties used for looking up and filtering EntityTags resources.
        :param pulumi.Input[builtins.str] guid: The guid of the entity to tag.
        :param pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]] tags: A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The guid of the entity to tag.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "guid", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]]:
        """
        A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EntityTagsTagArgs']]]]):
        pulumi.set(self, "tags", value)


class EntityTags(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 guid: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntityTagsTagArgs', 'EntityTagsTagArgsDict']]]]] = None,
                 __props__=None):
        """
        Use this resource to create, update, and delete tags for a New Relic One entity.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.get_entity(name="Example application",
            type="APPLICATION",
            domain="APM")
        foo_entity_tags = newrelic.EntityTags("foo",
            guid=foo.guid,
            tags=[
                {
                    "key": "my-key",
                    "values": [
                        "my-value",
                        "my-other-value",
                    ],
                },
                {
                    "key": "my-key-2",
                    "values": ["my-value-2"],
                },
            ])
        ```

        ## Import

        New Relic One entity tags can be imported using a concatenated string of the format

         `<guid>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/entityTags:EntityTags foo MjUyMDUyOHxBUE18QVBRTElDQVRJT058MjE1MDM3Nzk1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] guid: The guid of the entity to tag.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EntityTagsTagArgs', 'EntityTagsTagArgsDict']]]] tags: A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EntityTagsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update, and delete tags for a New Relic One entity.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.get_entity(name="Example application",
            type="APPLICATION",
            domain="APM")
        foo_entity_tags = newrelic.EntityTags("foo",
            guid=foo.guid,
            tags=[
                {
                    "key": "my-key",
                    "values": [
                        "my-value",
                        "my-other-value",
                    ],
                },
                {
                    "key": "my-key-2",
                    "values": ["my-value-2"],
                },
            ])
        ```

        ## Import

        New Relic One entity tags can be imported using a concatenated string of the format

         `<guid>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/entityTags:EntityTags foo MjUyMDUyOHxBUE18QVBRTElDQVRJT058MjE1MDM3Nzk1
        ```

        :param str resource_name: The name of the resource.
        :param EntityTagsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EntityTagsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 guid: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntityTagsTagArgs', 'EntityTagsTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EntityTagsArgs.__new__(EntityTagsArgs)

            if guid is None and not opts.urn:
                raise TypeError("Missing required property 'guid'")
            __props__.__dict__["guid"] = guid
            if tags is None and not opts.urn:
                raise TypeError("Missing required property 'tags'")
            __props__.__dict__["tags"] = tags
        super(EntityTags, __self__).__init__(
            'newrelic:index/entityTags:EntityTags',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            guid: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntityTagsTagArgs', 'EntityTagsTagArgsDict']]]]] = None) -> 'EntityTags':
        """
        Get an existing EntityTags resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] guid: The guid of the entity to tag.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EntityTagsTagArgs', 'EntityTagsTagArgsDict']]]] tags: A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EntityTagsState.__new__(_EntityTagsState)

        __props__.__dict__["guid"] = guid
        __props__.__dict__["tags"] = tags
        return EntityTags(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def guid(self) -> pulumi.Output[builtins.str]:
        """
        The guid of the entity to tag.
        """
        return pulumi.get(self, "guid")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.EntityTagsTag']]:
        """
        A nested block that describes an entity tag. See Nested tag blocks below for details.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 authentication_domain_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the group to be created would belong.
        :param pulumi.Input[builtins.str] name: The name of the group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_ids: A list of IDs of users to be included in the group to be created.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if user_ids is not None:
            pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the authentication domain to which the group to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @authentication_domain_id.setter
    def authentication_domain_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "authentication_domain_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the group to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of IDs of users to be included in the group to be created.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        return pulumi.get(self, "user_ids")

    @user_ids.setter
    def user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_ids", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the group to be created would belong.
        :param pulumi.Input[builtins.str] name: The name of the group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_ids: A list of IDs of users to be included in the group to be created.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        if authentication_domain_id is not None:
            pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if user_ids is not None:
            pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the authentication domain to which the group to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @authentication_domain_id.setter
    def authentication_domain_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_domain_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the group to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of IDs of users to be included in the group to be created.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        return pulumi.get(self, "user_ids")

    @user_ids.setter
    def user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_ids", value)


class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Import

        A group can be imported using its ID. Example:

        ```sh
        $ pulumi import newrelic:index/group:Group foo <group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the group to be created would belong.
        :param pulumi.Input[builtins.str] name: The name of the group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_ids: A list of IDs of users to be included in the group to be created.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        A group can be imported using its ID. Example:

        ```sh
        $ pulumi import newrelic:index/group:Group foo <group_id>
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            if authentication_domain_id is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_domain_id'")
            __props__.__dict__["authentication_domain_id"] = authentication_domain_id
            __props__.__dict__["name"] = name
            __props__.__dict__["user_ids"] = user_ids
        super(Group, __self__).__init__(
            'newrelic:index/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_domain_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_domain_id: The ID of the authentication domain to which the group to be created would belong.
        :param pulumi.Input[builtins.str] name: The name of the group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_ids: A list of IDs of users to be included in the group to be created.
               
               > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
               
               > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["authentication_domain_id"] = authentication_domain_id
        __props__.__dict__["name"] = name
        __props__.__dict__["user_ids"] = user_ids
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the authentication domain to which the group to be created would belong.
        """
        return pulumi.get(self, "authentication_domain_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the group to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of IDs of users to be included in the group to be created.

        > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.

        > **WARNING:** Changing the `authentication_domain_id` of a `Group` resource that has already been applied would result in a **replacement** of the resource – destruction of the existing resource, followed by the addition of a new resource with the specified configuration. This is due to the fact that updating the `authentication_domain_id` of an existing group is not supported.
        """
        return pulumi.get(self, "user_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NotificationChannelArgs', 'NotificationChannel']

@pulumi.input_type
class NotificationChannelArgs:
    def __init__(__self__, *,
                 destination_id: pulumi.Input[builtins.str],
                 product: pulumi.Input[builtins.str],
                 properties: pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]],
                 type: pulumi.Input[builtins.str],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NotificationChannel resource.
        :param pulumi.Input[builtins.str] destination_id: The id of the destination.
        :param pulumi.Input[builtins.str] product: The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        :param pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]] properties: A nested block that describes a notification channel property. See Nested property blocks below for details.
        :param pulumi.Input[builtins.str] type: The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        :param pulumi.Input[builtins.str] account_id: Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[builtins.bool] active: Indicates whether the channel is active.
        :param pulumi.Input[builtins.str] name: The name of the channel.
        """
        pulumi.set(__self__, "destination_id", destination_id)
        pulumi.set(__self__, "product", product)
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "type", type)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="destinationId")
    def destination_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the destination.
        """
        return pulumi.get(self, "destination_id")

    @destination_id.setter
    def destination_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_id", value)

    @property
    @pulumi.getter
    def product(self) -> pulumi.Input[builtins.str]:
        """
        The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        """
        return pulumi.get(self, "product")

    @product.setter
    def product(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "product", value)

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]]:
        """
        A nested block that describes a notification channel property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates whether the channel is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NotificationChannelState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 destination_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NotificationChannel resources.
        :param pulumi.Input[builtins.str] account_id: Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[builtins.bool] active: Indicates whether the channel is active.
        :param pulumi.Input[builtins.str] destination_id: The id of the destination.
        :param pulumi.Input[builtins.str] name: The name of the channel.
        :param pulumi.Input[builtins.str] product: The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        :param pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]] properties: A nested block that describes a notification channel property. See Nested property blocks below for details.
        :param pulumi.Input[builtins.str] status: The status of the channel.
        :param pulumi.Input[builtins.str] type: The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if destination_id is not None:
            pulumi.set(__self__, "destination_id", destination_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if product is not None:
            pulumi.set(__self__, "product", product)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates whether the channel is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="destinationId")
    def destination_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the destination.
        """
        return pulumi.get(self, "destination_id")

    @destination_id.setter
    def destination_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the channel.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def product(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        """
        return pulumi.get(self, "product")

    @product.setter
    def product(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "product", value)

    @property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]]]:
        """
        A nested block that describes a notification channel property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationChannelPropertyArgs']]]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the channel.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


class NotificationChannel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 destination_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationChannelPropertyArgs', 'NotificationChannelPropertyArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create and manage New Relic notification channels. Details regarding supported products and permissions can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/destinations).

        A channel is an entity that is used to configure notifications. It is also called a message template. It is a separate entity from workflows, but a channel is required in order to create a workflow.

        ## Example Usage

        ##### [Webhook](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#webhook)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="webhook-example",
            type="WEBHOOK",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "name: {{ foo }}",
                "label": "Payload Template",
            }])
        ```
        See additional examples.

        ## Additional Examples

        > **NOTE:** We support all properties. The mentioned properties are just an example.

        ##### [ServiceNow](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#servicenow)
        To see the properties’ keys for your account, check ServiceNow incidents table.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="servicenow-incident-example",
            type="SERVICENOW_INCIDENTS",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "description",
                    "value": "General description",
                },
                {
                    "key": "short_description",
                    "value": "Short description",
                },
            ])
        ```
        ##### [ServiceNowApp](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#servicenowapp)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="servicenow-app-example",
            type="SERVICE_NOW_APP",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT")
        ```

        ##### [Email](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#email)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="email-example",
            type="EMAIL",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "subject",
                    "value": "New Subject Title",
                },
                {
                    "key": "customDetailsEmail",
                    "value": "issue id - {{issueId}}",
                },
            ])
        ```

        ##### [Jira Classic](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#jira)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="jira-example",
            type="JIRA_CLASSIC",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="ERROR_TRACKING",
            properties=[
                {
                    "key": "project",
                    "value": "10000",
                    "label": "Project-Name",
                },
                {
                    "key": "issuetype",
                    "value": "10004",
                    "label": "Bug",
                },
                {
                    "key": "description",
                    "value": "Issue ID: {{ issueId }}",
                },
                {
                    "key": "summary",
                    "value": "{{ annotations.title.[0] }}",
                },
            ])
        ```

        ##### [PagerDuty with account integration](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#pagerduty)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_ACCOUNT_INTEGRATION",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "summary",
                    "value": "General summary",
                },
                {
                    "key": "service",
                    "label": "Service Name",
                    "value": "PTQK3FM",
                },
                {
                    "key": "email",
                    "value": "example@email.com",
                },
                {
                    "key": "customDetails",
                    "value": \"\"\"{
        "id":{{json issueId}},
        "IssueURL":{{json issuePageUrl}},
        "NewRelic priority":{{json priority}},
        "Total Incidents":{{json totalIncidents}},
        "Impacted Entities":"{{#each entitiesData.names}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Runbook":"{{#each accumulations.runbookUrl}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Description":"{{#each annotations.description}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "isCorrelated":{{json isCorrelated}},
        "Alert Policy Names":"{{#each accumulations.policyName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Alert Condition Names":"{{#each accumulations.conditionName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Workflow Name":{{json workflowName}}
        }
        \"\"\",
                },
            ])
        ```

        ##### [PagerDuty with service integration](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#pagerduty)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_SERVICE_INTEGRATION",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "summary",
                    "value": "General summary",
                },
                {
                    "key": "customDetails",
                    "value": \"\"\"{
        "id":{{json issueId}},
        "IssueURL":{{json issuePageUrl}},
        "NewRelic priority":{{json priority}},
        "Total Incidents":{{json totalIncidents}},
        "Impacted Entities":"{{#each entitiesData.names}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Runbook":"{{#each accumulations.runbookUrl}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Description":"{{#each annotations.description}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "isCorrelated":{{json isCorrelated}},
        "Alert Policy Names":"{{#each accumulations.policyName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Alert Condition Names":"{{#each accumulations.conditionName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Workflow Name":{{json workflowName}}
        }
        \"\"\",
                },
            ])
        ```

        #### Mobile Push
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="mobile-push-example",
            type="MOBILE_PUSH",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT")
        ```

        #### [AWS Event Bridge](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#eventBridge)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="event-bridge-example",
            type="EVENT_BRIDGE",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "eventSource",
                    "value": "aws.partner/mydomain/myaccountid/name",
                },
                {
                    "key": "eventContent",
                    "value": "{ id: {{ json issueId }} }",
                },
            ])
        ```

        #### [SLACK](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#slack)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="slack-example",
            type="SLACK",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "channelId",
                    "value": "123456",
                },
                {
                    "key": "customDetailsSlack",
                    "value": "issue id - {{issueId}}",
                },
            ])
        ```

        #### [MICROSOFT_TEAMS]
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="ms-teams-example",
            type="MICROSOFT_TEAMS",
            destination_id="52d36b54-3d68-4ac4-9d0a-581febb91f2c",
            product="IINT",
            properties=[
                {
                    "key": "teamId",
                    "value": "906379b4-f5ac-40fd-b242-d4faaa4d3963",
                },
                {
                    "key": "channelId",
                    "value": "19:wk9tU4tSr335Y1cNiXOynredbi3lFoeabu0kybfmbBA1@thread.tacv2",
                },
                {
                    "key": "customDetails",
                    "value": "{{ nrAccountId }}",
                },
            ])
        ```

        > **NOTE:** Sensitive data such as channel API keys, service keys, etc are not returned from the underlying API for security reasons and may not be set in state when importing.

        ## Full Scenario Example

        Create a destination resource and reference that destination to the channel resource:

        ### Create a destination
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        webhook_destination = newrelic.NotificationDestination("webhook-destination",
            account_id="12345678",
            name="destination-webhook",
            type="WEBHOOK",
            properties=[{
                "key": "url",
                "value": "https://webhook.mywebhook.com",
            }],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        ```

        ### Create a channel
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        webhook_channel = newrelic.NotificationChannel("webhook-channel",
            account_id="12345678",
            name="channel-webhook",
            type="WEBHOOK",
            destination_id=webhook_destination["id"],
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "{name: foo}",
                "label": "Payload Template",
            }])
        ```

        ## Additional Information

        More details about the channels API can be found [here](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels).
        ### Moving from Legacy Alert Channels to Notification Channels
        As described in the documentation of this resource, channels can be created and managed using `NotificationDestination` and `NotificationChannel`. A combination of these resources is an alternative to the legacy resource `AlertChannel`, which is **deprecated** and will be **removed in a future major release**, as stated in the documentation of the resource.

        If you're currently using `AlertChannel` to manage channels, we **strongly recommend** migrating to these notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels with these resources.

        ## Import

        Channels can only be used by a single workflow, therefore importing them is not particularly useful, because in the UI channels are created upon workflow creation.

        Additionally, the channel id isn't available via the UI, and you'd need to look it up with the `channels` query in the NerdGraph API.

        That being said, importing is possible using -

        ```sh
        $ pulumi import newrelic:index/notificationChannel:NotificationChannel foo <destination_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[builtins.bool] active: Indicates whether the channel is active.
        :param pulumi.Input[builtins.str] destination_id: The id of the destination.
        :param pulumi.Input[builtins.str] name: The name of the channel.
        :param pulumi.Input[builtins.str] product: The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationChannelPropertyArgs', 'NotificationChannelPropertyArgsDict']]]] properties: A nested block that describes a notification channel property. See Nested property blocks below for details.
        :param pulumi.Input[builtins.str] type: The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NotificationChannelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create and manage New Relic notification channels. Details regarding supported products and permissions can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/destinations).

        A channel is an entity that is used to configure notifications. It is also called a message template. It is a separate entity from workflows, but a channel is required in order to create a workflow.

        ## Example Usage

        ##### [Webhook](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#webhook)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="webhook-example",
            type="WEBHOOK",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "name: {{ foo }}",
                "label": "Payload Template",
            }])
        ```
        See additional examples.

        ## Additional Examples

        > **NOTE:** We support all properties. The mentioned properties are just an example.

        ##### [ServiceNow](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#servicenow)
        To see the properties’ keys for your account, check ServiceNow incidents table.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="servicenow-incident-example",
            type="SERVICENOW_INCIDENTS",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "description",
                    "value": "General description",
                },
                {
                    "key": "short_description",
                    "value": "Short description",
                },
            ])
        ```
        ##### [ServiceNowApp](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#servicenowapp)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="servicenow-app-example",
            type="SERVICE_NOW_APP",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT")
        ```

        ##### [Email](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#email)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="email-example",
            type="EMAIL",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "subject",
                    "value": "New Subject Title",
                },
                {
                    "key": "customDetailsEmail",
                    "value": "issue id - {{issueId}}",
                },
            ])
        ```

        ##### [Jira Classic](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#jira)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="jira-example",
            type="JIRA_CLASSIC",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="ERROR_TRACKING",
            properties=[
                {
                    "key": "project",
                    "value": "10000",
                    "label": "Project-Name",
                },
                {
                    "key": "issuetype",
                    "value": "10004",
                    "label": "Bug",
                },
                {
                    "key": "description",
                    "value": "Issue ID: {{ issueId }}",
                },
                {
                    "key": "summary",
                    "value": "{{ annotations.title.[0] }}",
                },
            ])
        ```

        ##### [PagerDuty with account integration](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#pagerduty)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_ACCOUNT_INTEGRATION",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "summary",
                    "value": "General summary",
                },
                {
                    "key": "service",
                    "label": "Service Name",
                    "value": "PTQK3FM",
                },
                {
                    "key": "email",
                    "value": "example@email.com",
                },
                {
                    "key": "customDetails",
                    "value": \"\"\"{
        "id":{{json issueId}},
        "IssueURL":{{json issuePageUrl}},
        "NewRelic priority":{{json priority}},
        "Total Incidents":{{json totalIncidents}},
        "Impacted Entities":"{{#each entitiesData.names}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Runbook":"{{#each accumulations.runbookUrl}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Description":"{{#each annotations.description}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "isCorrelated":{{json isCorrelated}},
        "Alert Policy Names":"{{#each accumulations.policyName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Alert Condition Names":"{{#each accumulations.conditionName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Workflow Name":{{json workflowName}}
        }
        \"\"\",
                },
            ])
        ```

        ##### [PagerDuty with service integration](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#pagerduty)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_SERVICE_INTEGRATION",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "summary",
                    "value": "General summary",
                },
                {
                    "key": "customDetails",
                    "value": \"\"\"{
        "id":{{json issueId}},
        "IssueURL":{{json issuePageUrl}},
        "NewRelic priority":{{json priority}},
        "Total Incidents":{{json totalIncidents}},
        "Impacted Entities":"{{#each entitiesData.names}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Runbook":"{{#each accumulations.runbookUrl}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Description":"{{#each annotations.description}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "isCorrelated":{{json isCorrelated}},
        "Alert Policy Names":"{{#each accumulations.policyName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Alert Condition Names":"{{#each accumulations.conditionName}}{{this}}{{#unless @last}}, {{/unless}}{{/each}}",
        "Workflow Name":{{json workflowName}}
        }
        \"\"\",
                },
            ])
        ```

        #### Mobile Push
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="mobile-push-example",
            type="MOBILE_PUSH",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT")
        ```

        #### [AWS Event Bridge](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#eventBridge)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="event-bridge-example",
            type="EVENT_BRIDGE",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "eventSource",
                    "value": "aws.partner/mydomain/myaccountid/name",
                },
                {
                    "key": "eventContent",
                    "value": "{ id: {{ json issueId }} }",
                },
            ])
        ```

        #### [SLACK](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels/#slack)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="slack-example",
            type="SLACK",
            destination_id="00b6bd1d-ac06-4d3d-bd72-49551e70f7a8",
            product="IINT",
            properties=[
                {
                    "key": "channelId",
                    "value": "123456",
                },
                {
                    "key": "customDetailsSlack",
                    "value": "issue id - {{issueId}}",
                },
            ])
        ```

        #### [MICROSOFT_TEAMS]
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationChannel("foo",
            account_id="12345678",
            name="ms-teams-example",
            type="MICROSOFT_TEAMS",
            destination_id="52d36b54-3d68-4ac4-9d0a-581febb91f2c",
            product="IINT",
            properties=[
                {
                    "key": "teamId",
                    "value": "906379b4-f5ac-40fd-b242-d4faaa4d3963",
                },
                {
                    "key": "channelId",
                    "value": "19:wk9tU4tSr335Y1cNiXOynredbi3lFoeabu0kybfmbBA1@thread.tacv2",
                },
                {
                    "key": "customDetails",
                    "value": "{{ nrAccountId }}",
                },
            ])
        ```

        > **NOTE:** Sensitive data such as channel API keys, service keys, etc are not returned from the underlying API for security reasons and may not be set in state when importing.

        ## Full Scenario Example

        Create a destination resource and reference that destination to the channel resource:

        ### Create a destination
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        webhook_destination = newrelic.NotificationDestination("webhook-destination",
            account_id="12345678",
            name="destination-webhook",
            type="WEBHOOK",
            properties=[{
                "key": "url",
                "value": "https://webhook.mywebhook.com",
            }],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        ```

        ### Create a channel
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        webhook_channel = newrelic.NotificationChannel("webhook-channel",
            account_id="12345678",
            name="channel-webhook",
            type="WEBHOOK",
            destination_id=webhook_destination["id"],
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "{name: foo}",
                "label": "Payload Template",
            }])
        ```

        ## Additional Information

        More details about the channels API can be found [here](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-channels).
        ### Moving from Legacy Alert Channels to Notification Channels
        As described in the documentation of this resource, channels can be created and managed using `NotificationDestination` and `NotificationChannel`. A combination of these resources is an alternative to the legacy resource `AlertChannel`, which is **deprecated** and will be **removed in a future major release**, as stated in the documentation of the resource.

        If you're currently using `AlertChannel` to manage channels, we **strongly recommend** migrating to these notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels with these resources.

        ## Import

        Channels can only be used by a single workflow, therefore importing them is not particularly useful, because in the UI channels are created upon workflow creation.

        Additionally, the channel id isn't available via the UI, and you'd need to look it up with the `channels` query in the NerdGraph API.

        That being said, importing is possible using -

        ```sh
        $ pulumi import newrelic:index/notificationChannel:NotificationChannel foo <destination_id>
        ```

        :param str resource_name: The name of the resource.
        :param NotificationChannelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NotificationChannelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 destination_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationChannelPropertyArgs', 'NotificationChannelPropertyArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NotificationChannelArgs.__new__(NotificationChannelArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["active"] = active
            if destination_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_id'")
            __props__.__dict__["destination_id"] = destination_id
            __props__.__dict__["name"] = name
            if product is None and not opts.urn:
                raise TypeError("Missing required property 'product'")
            __props__.__dict__["product"] = product
            if properties is None and not opts.urn:
                raise TypeError("Missing required property 'properties'")
            __props__.__dict__["properties"] = properties
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["status"] = None
        super(NotificationChannel, __self__).__init__(
            'newrelic:index/notificationChannel:NotificationChannel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            active: Optional[pulumi.Input[builtins.bool]] = None,
            destination_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            product: Optional[pulumi.Input[builtins.str]] = None,
            properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationChannelPropertyArgs', 'NotificationChannelPropertyArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'NotificationChannel':
        """
        Get an existing NotificationChannel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[builtins.bool] active: Indicates whether the channel is active.
        :param pulumi.Input[builtins.str] destination_id: The id of the destination.
        :param pulumi.Input[builtins.str] name: The name of the channel.
        :param pulumi.Input[builtins.str] product: The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationChannelPropertyArgs', 'NotificationChannelPropertyArgsDict']]]] properties: A nested block that describes a notification channel property. See Nested property blocks below for details.
        :param pulumi.Input[builtins.str] status: The status of the channel.
        :param pulumi.Input[builtins.str] type: The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NotificationChannelState.__new__(_NotificationChannelState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["active"] = active
        __props__.__dict__["destination_id"] = destination_id
        __props__.__dict__["name"] = name
        __props__.__dict__["product"] = product
        __props__.__dict__["properties"] = properties
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return NotificationChannel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        Determines the New Relic account where the notification channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Indicates whether the channel is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="destinationId")
    def destination_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the destination.
        """
        return pulumi.get(self, "destination_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the channel.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def product(self) -> pulumi.Output[builtins.str]:
        """
        The type of product.  One of: `DISCUSSIONS`, `ERROR_TRACKING` or `IINT` (workflows).
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Sequence['outputs.NotificationChannelProperty']]:
        """
        A nested block that describes a notification channel property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the channel.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The type of channel.  One of: `EMAIL`, `SERVICENOW_INCIDENTS`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA_CLASSIC`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `SLACK` and `SLACK_COLLABORATION`, `PAGERDUTY_ACCOUNT_INTEGRATION`, `PAGERDUTY_SERVICE_INTEGRATION` or `MICROSOFT_TEAMS`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertMutingRuleArgs', 'AlertMutingRule']

@pulumi.input_type
class AlertMutingRuleArgs:
    def __init__(__self__, *,
                 condition: pulumi.Input['AlertMutingRuleConditionArgs'],
                 enabled: pulumi.Input[builtins.bool],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 action_on_muting_rule_window_ended: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AlertMutingRuleScheduleArgs']] = None):
        """
        The set of arguments for constructing a AlertMutingRule resource.
        :param pulumi.Input['AlertMutingRuleConditionArgs'] condition: The condition that defines which incidents to target. See Nested condition blocks below for details.
        :param pulumi.Input[builtins.bool] enabled: Whether the MutingRule is enabled.
        :param pulumi.Input[builtins.str] account_id: The account id of the MutingRule.
        :param pulumi.Input[builtins.str] action_on_muting_rule_window_ended: The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        :param pulumi.Input[builtins.str] description: The description of the MutingRule.
        :param pulumi.Input[builtins.str] name: The name of the MutingRule.
        :param pulumi.Input['AlertMutingRuleScheduleArgs'] schedule: Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        pulumi.set(__self__, "condition", condition)
        pulumi.set(__self__, "enabled", enabled)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if action_on_muting_rule_window_ended is not None:
            pulumi.set(__self__, "action_on_muting_rule_window_ended", action_on_muting_rule_window_ended)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @property
    @pulumi.getter
    def condition(self) -> pulumi.Input['AlertMutingRuleConditionArgs']:
        """
        The condition that defines which incidents to target. See Nested condition blocks below for details.
        """
        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: pulumi.Input['AlertMutingRuleConditionArgs']):
        pulumi.set(self, "condition", value)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[builtins.bool]:
        """
        Whether the MutingRule is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account id of the MutingRule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="actionOnMutingRuleWindowEnded")
    def action_on_muting_rule_window_ended(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        """
        return pulumi.get(self, "action_on_muting_rule_window_ended")

    @action_on_muting_rule_window_ended.setter
    def action_on_muting_rule_window_ended(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action_on_muting_rule_window_ended", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the MutingRule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the MutingRule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertMutingRuleScheduleArgs']]:
        """
        Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertMutingRuleScheduleArgs']]):
        pulumi.set(self, "schedule", value)


@pulumi.input_type
class _AlertMutingRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 action_on_muting_rule_window_ended: Optional[pulumi.Input[builtins.str]] = None,
                 condition: Optional[pulumi.Input['AlertMutingRuleConditionArgs']] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AlertMutingRuleScheduleArgs']] = None):
        """
        Input properties used for looking up and filtering AlertMutingRule resources.
        :param pulumi.Input[builtins.str] account_id: The account id of the MutingRule.
        :param pulumi.Input[builtins.str] action_on_muting_rule_window_ended: The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        :param pulumi.Input['AlertMutingRuleConditionArgs'] condition: The condition that defines which incidents to target. See Nested condition blocks below for details.
        :param pulumi.Input[builtins.str] description: The description of the MutingRule.
        :param pulumi.Input[builtins.bool] enabled: Whether the MutingRule is enabled.
        :param pulumi.Input[builtins.str] name: The name of the MutingRule.
        :param pulumi.Input['AlertMutingRuleScheduleArgs'] schedule: Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if action_on_muting_rule_window_ended is not None:
            pulumi.set(__self__, "action_on_muting_rule_window_ended", action_on_muting_rule_window_ended)
        if condition is not None:
            pulumi.set(__self__, "condition", condition)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account id of the MutingRule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="actionOnMutingRuleWindowEnded")
    def action_on_muting_rule_window_ended(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        """
        return pulumi.get(self, "action_on_muting_rule_window_ended")

    @action_on_muting_rule_window_ended.setter
    def action_on_muting_rule_window_ended(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action_on_muting_rule_window_ended", value)

    @property
    @pulumi.getter
    def condition(self) -> Optional[pulumi.Input['AlertMutingRuleConditionArgs']]:
        """
        The condition that defines which incidents to target. See Nested condition blocks below for details.
        """
        return pulumi.get(self, "condition")

    @condition.setter
    def condition(self, value: Optional[pulumi.Input['AlertMutingRuleConditionArgs']]):
        pulumi.set(self, "condition", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the MutingRule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the MutingRule is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the MutingRule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertMutingRuleScheduleArgs']]:
        """
        Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertMutingRuleScheduleArgs']]):
        pulumi.set(self, "schedule", value)


class AlertMutingRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 action_on_muting_rule_window_ended: Optional[pulumi.Input[builtins.str]] = None,
                 condition: Optional[pulumi.Input[Union['AlertMutingRuleConditionArgs', 'AlertMutingRuleConditionArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertMutingRuleScheduleArgs', 'AlertMutingRuleScheduleArgsDict']]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.AlertMutingRule("foo",
            name="Example Muting Rule",
            enabled=True,
            description="muting rule test.",
            condition={
                "conditions": [
                    {
                        "attribute": "product",
                        "operator": "EQUALS",
                        "values": ["APM"],
                    },
                    {
                        "attribute": "targetId",
                        "operator": "EQUALS",
                        "values": ["Muted"],
                    },
                ],
                "operator": "AND",
            },
            schedule={
                "start_time": "2021-01-28T15:30:00",
                "end_time": "2021-01-28T16:30:00",
                "time_zone": "America/Los_Angeles",
                "repeat": "WEEKLY",
                "weekly_repeat_days": [
                    "MONDAY",
                    "WEDNESDAY",
                    "FRIDAY",
                ],
                "repeat_count": 42,
            },
            action_on_muting_rule_window_ended="CLOSE_ISSUES_ON_INACTIVE")
        ```

        ## Import

        Alert conditions can be imported using a composite ID of `<account_id>:<muting_rule_id>`, e.g.

        ```sh
        $ pulumi import newrelic:index/alertMutingRule:AlertMutingRule foo 538291:6789035
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account id of the MutingRule.
        :param pulumi.Input[builtins.str] action_on_muting_rule_window_ended: The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        :param pulumi.Input[Union['AlertMutingRuleConditionArgs', 'AlertMutingRuleConditionArgsDict']] condition: The condition that defines which incidents to target. See Nested condition blocks below for details.
        :param pulumi.Input[builtins.str] description: The description of the MutingRule.
        :param pulumi.Input[builtins.bool] enabled: Whether the MutingRule is enabled.
        :param pulumi.Input[builtins.str] name: The name of the MutingRule.
        :param pulumi.Input[Union['AlertMutingRuleScheduleArgs', 'AlertMutingRuleScheduleArgsDict']] schedule: Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertMutingRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.AlertMutingRule("foo",
            name="Example Muting Rule",
            enabled=True,
            description="muting rule test.",
            condition={
                "conditions": [
                    {
                        "attribute": "product",
                        "operator": "EQUALS",
                        "values": ["APM"],
                    },
                    {
                        "attribute": "targetId",
                        "operator": "EQUALS",
                        "values": ["Muted"],
                    },
                ],
                "operator": "AND",
            },
            schedule={
                "start_time": "2021-01-28T15:30:00",
                "end_time": "2021-01-28T16:30:00",
                "time_zone": "America/Los_Angeles",
                "repeat": "WEEKLY",
                "weekly_repeat_days": [
                    "MONDAY",
                    "WEDNESDAY",
                    "FRIDAY",
                ],
                "repeat_count": 42,
            },
            action_on_muting_rule_window_ended="CLOSE_ISSUES_ON_INACTIVE")
        ```

        ## Import

        Alert conditions can be imported using a composite ID of `<account_id>:<muting_rule_id>`, e.g.

        ```sh
        $ pulumi import newrelic:index/alertMutingRule:AlertMutingRule foo 538291:6789035
        ```

        :param str resource_name: The name of the resource.
        :param AlertMutingRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertMutingRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 action_on_muting_rule_window_ended: Optional[pulumi.Input[builtins.str]] = None,
                 condition: Optional[pulumi.Input[Union['AlertMutingRuleConditionArgs', 'AlertMutingRuleConditionArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertMutingRuleScheduleArgs', 'AlertMutingRuleScheduleArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertMutingRuleArgs.__new__(AlertMutingRuleArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["action_on_muting_rule_window_ended"] = action_on_muting_rule_window_ended
            if condition is None and not opts.urn:
                raise TypeError("Missing required property 'condition'")
            __props__.__dict__["condition"] = condition
            __props__.__dict__["description"] = description
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["schedule"] = schedule
        super(AlertMutingRule, __self__).__init__(
            'newrelic:index/alertMutingRule:AlertMutingRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            action_on_muting_rule_window_ended: Optional[pulumi.Input[builtins.str]] = None,
            condition: Optional[pulumi.Input[Union['AlertMutingRuleConditionArgs', 'AlertMutingRuleConditionArgsDict']]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['AlertMutingRuleScheduleArgs', 'AlertMutingRuleScheduleArgsDict']]] = None) -> 'AlertMutingRule':
        """
        Get an existing AlertMutingRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account id of the MutingRule.
        :param pulumi.Input[builtins.str] action_on_muting_rule_window_ended: The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        :param pulumi.Input[Union['AlertMutingRuleConditionArgs', 'AlertMutingRuleConditionArgsDict']] condition: The condition that defines which incidents to target. See Nested condition blocks below for details.
        :param pulumi.Input[builtins.str] description: The description of the MutingRule.
        :param pulumi.Input[builtins.bool] enabled: Whether the MutingRule is enabled.
        :param pulumi.Input[builtins.str] name: The name of the MutingRule.
        :param pulumi.Input[Union['AlertMutingRuleScheduleArgs', 'AlertMutingRuleScheduleArgsDict']] schedule: Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertMutingRuleState.__new__(_AlertMutingRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["action_on_muting_rule_window_ended"] = action_on_muting_rule_window_ended
        __props__.__dict__["condition"] = condition
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["schedule"] = schedule
        return AlertMutingRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        The account id of the MutingRule.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="actionOnMutingRuleWindowEnded")
    def action_on_muting_rule_window_ended(self) -> pulumi.Output[builtins.str]:
        """
        The action when the muting rule window is ended or disabled. Valid values are `CLOSE_ISSUES_ON_INACTIVE`, `DO_NOTHING`.
        """
        return pulumi.get(self, "action_on_muting_rule_window_ended")

    @property
    @pulumi.getter
    def condition(self) -> pulumi.Output['outputs.AlertMutingRuleCondition']:
        """
        The condition that defines which incidents to target. See Nested condition blocks below for details.
        """
        return pulumi.get(self, "condition")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the MutingRule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Whether the MutingRule is enabled.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the MutingRule.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[Optional['outputs.AlertMutingRuleSchedule']]:
        """
        Specify a schedule for enabling the MutingRule. See Schedule below for details
        """
        return pulumi.get(self, "schedule")

